@@ -129,6 +129,9 @@ int         moment_nanosecond(const moment_t *mt);
 int         moment_offset(const moment_t *mt);
 int64_t     moment_epoch(const moment_t *mt);
 
+NV          moment_jd(const moment_t *mt);
+NV          moment_mjd(const moment_t *mt);
+
 int         moment_length_of_year(const moment_t *mt);
 int         moment_length_of_quarter(const moment_t *mt);
 int         moment_length_of_month(const moment_t *mt);
